==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/TallMushroomBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import java.util.Optional;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2256;
import net.minecraft.class_2320;
import net.minecraft.class_2338;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2756;
import net.minecraft.class_2975;
import net.minecraft.class_3218;
import net.minecraft.class_3481;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import net.minecraft.class_5321;
import net.minecraft.class_5819;
import net.minecraft.class_6880;
import net.minecraft.class_7924;

public class TallMushroomBlock extends class_2320 implements class_2256 {
	private static final class_265 UPPER = class_2248.method_9541(2.0D, 0.0D, 2.0D, 14.0D, 14.0D, 14.0D);
	private static final class_265 LOWER = class_2248.method_9541(2.0D, 0.0D, 2.0D, 14.0D, 16.0D, 14.0D);
	private final class_5321<class_2975<?, ?>> feature;

	public TallMushroomBlock(class_5321<class_2975<?, ?>> feature, class_2251 properties) {
		super(properties);
		this.feature = feature;
	}

	public boolean method_9651(class_4538 level, class_2338 pos, class_2680 state) {
		return true;
	}

	public boolean method_9650(class_1937 level, class_5819 random, class_2338 pos, class_2680 state) {
		return random.method_43057() < 0.25F;
	}

	public void method_9652(class_3218 level, class_5819 random, class_2338 pos, class_2680 state) {
		Optional<class_6880.class_6883<class_2975<?, ?>>> optional = level.method_30349().method_30530(class_7924.field_41239).method_40264(feature);
		if (optional.isEmpty()) return;

		if (state.method_11654(field_10929).equals(class_2756.field_12609)) pos = pos.method_10074();

		level.method_8650(pos, false);
		level.method_8650(pos.method_10084(), false);
		if (optional.get().comp_349().method_12862(level, level.method_14178().method_12129(), random, pos)) return;

		level.method_8652(pos, state.method_11657(field_10929, class_2756.field_12607), 3);
		level.method_8652(pos.method_10084(), state.method_11657(field_10929, class_2756.field_12609), 3);
	}

	public class_265 method_9530(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
		return state.method_11654(field_10929) == class_2756.field_12607 ? LOWER : UPPER;
	}

	protected boolean method_9695(class_2680 state, class_1922 level, class_2338 pos) {
		return state.method_26216(level, pos);
	}

	public boolean method_9558(class_2680 state, class_4538 level, class_2338 pos) {
		class_2338 blockPos = pos.method_10074();
		class_2680 blockState = level.method_8320(blockPos);
		if (blockState.method_27852(this) && state.method_11654(field_10929) == class_2756.field_12609 && blockState.method_11654(field_10929) == class_2756.field_12607) return true;
		if (blockState.method_26164(class_3481.field_25739)) return true;
		return level.method_22335(pos, 0) < 13 && method_9695(blockState, level, blockPos);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/TallMushroomBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import java.util.Optional;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2256;
import net.minecraft.class_2320;
import net.minecraft.class_2338;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2756;
import net.minecraft.class_2975;
import net.minecraft.class_3218;
import net.minecraft.class_3481;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import net.minecraft.class_5321;
import net.minecraft.class_5819;
import net.minecraft.class_6880;
import net.minecraft.class_7924;

public class TallMushroomBlock extends class_2320 implements class_2256 {
	private static final class_265 UPPER = class_2248.method_9541(2.0D, 0.0D, 2.0D, 14.0D, 14.0D, 14.0D);
	private static final class_265 LOWER = class_2248.method_9541(2.0D, 0.0D, 2.0D, 14.0D, 16.0D, 14.0D);
	private final class_5321<class_2975<?, ?>> feature;

	public TallMushroomBlock(class_5321<class_2975<?, ?>> feature, class_2251 properties) {
		super(properties);
		this.feature = feature;
	}

	public boolean method_9651(class_4538 level, class_2338 pos, class_2680 state) {
		return true;
	}

	public boolean method_9650(class_1937 level, class_5819 random, class_2338 pos, class_2680 state) {
		return random.method_43057() < 0.25F;
	}

	public void method_9652(class_3218 level, class_5819 random, class_2338 pos, class_2680 state) {
		Optional<class_6880.class_6883<class_2975<?, ?>>> optional = level.method_30349().method_30530(class_7924.field_41239).method_46746(feature);
		if (optional.isEmpty()) return;

		if (state.method_11654(field_10929).equals(class_2756.field_12609)) pos = pos.method_10074();

		level.method_8650(pos, false);
		level.method_8650(pos.method_10084(), false);
		if (optional.get().comp_349().method_12862(level, level.method_14178().method_12129(), random, pos)) return;

		level.method_8652(pos, state.method_11657(field_10929, class_2756.field_12607), 3);
		level.method_8652(pos.method_10084(), state.method_11657(field_10929, class_2756.field_12609), 3);
	}

	public class_265 method_9530(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
		return state.method_11654(field_10929) == class_2756.field_12607 ? LOWER : UPPER;
	}

	protected boolean method_9695(class_2680 state, class_1922 level, class_2338 pos) {
		return state.method_26216();
	}

	public boolean method_9558(class_2680 state, class_4538 level, class_2338 pos) {
		class_2338 blockPos = pos.method_10074();
		class_2680 blockState = level.method_8320(blockPos);
		if (blockState.method_27852(this) && state.method_11654(field_10929) == class_2756.field_12609 && blockState.method_11654(field_10929) == class_2756.field_12607) return true;
		if (blockState.method_26164(class_3481.field_25739)) return true;
		return level.method_22335(pos, 0) < 13 && method_9695(blockState, level, blockPos);
	}
}
